<?php # $Id: serendipity_lang_ko.inc.php 1815 2007-08-06 10:18:26Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translated by: Wesley Hwang-Chung <wesley96@gmail.com>
# (c) 2005 http://www.tool-box.info/
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'UTF-8');
@define('SQL_CHARSET', 'utf8');
@define('DATE_LOCALES', 'ko_KR.UTF-8, korean, ko, ko_KR');
@define('DATE_FORMAT_ENTRY', '%Y년 %B %e일 %A');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'en');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', '세렌디피티 관리 도구');
@define('HAVE_TO_BE_LOGGED_ON', '이 페이지를 보려면 로그인해야 합니다');
@define('WRONG_USERNAME_OR_PASSWORD', '아이디 또는 암호가 잘못 입력되었습니다');
@define('APPEARANCE', '시각적 요소');
@define('MANAGE_STYLES', '스타일 관리');
@define('CONFIGURE_PLUGINS', '플러그인 설정');
@define('CONFIGURATION', '기능 설정');
@define('BACK_TO_BLOG', '블로그로 돌아가기');
@define('LOGIN', '로그인');
@define('LOGOUT', '로그아웃');
@define('LOGGEDOUT', '로그아웃 되었습니다.');
@define('CREATE', '생성');
@define('SAVE', '저장');
@define('NAME', '이름');
@define('CREATE_NEW_CAT', '새로운 범주 만들기');
@define('I_WANT_THUMB', '글에 작은 그림을 적용합니다.');
@define('I_WANT_BIG_IMAGE', '글에 큰 그림을 적용합니다.');
@define('I_WANT_NO_LINK', '그림 자체로 보여줍니다');
@define('I_WANT_IT_TO_LINK', '그림을 다음 주소의 링크로 만듭니다:');
@define('BACK', '뒤로');
@define('FORWARD', '앞으로');
@define('ANONYMOUS', '익명');
@define('NEW_TRACKBACK_TO', '다음 글에 새로운 트랙백을 만들었습니다:');
@define('NEW_COMMENT_TO', '다음 글에 새 덧글을 달았습니다:');
@define('RECENT', '최근 글...');
@define('OLDER', '예전 글...');
@define('DONE', '완료');
@define('WELCOME_BACK', '돌아와서 반갑습니다,');
@define('TITLE', '제목');
@define('DESCRIPTION', '설명');
@define('PLACEMENT', '위치');
@define('DELETE', '삭제');
@define('SAVE', '저장');
@define('UP', '위로');
@define('DOWN', '아래로');
@define('ENTRIES', '개의 글');
@define('NEW_ENTRY', '새로운 글');
@define('EDIT_ENTRIES', '글 편집하기');
@define('CATEGORIES', '범주');
@define('WARNING_THIS_BLAHBLAH', "경고:\\n작은 그림이 생성되지 않은 그림이 많이 있을 경우 오래 걸릴 수 있습니다.");
@define('CREATE_THUMBS', '작은 그림 재생성');
@define('MANAGE_IMAGES', '그림 관리');
@define('NAME', '작성자 이름');
@define('EMAIL', '전자우편');
@define('HOMEPAGE', '홈페이지 주소(URL)');
@define('COMMENT', '덧글');
@define('REMEMBER_INFO', '입력 정보 기억하기');
@define('SUBMIT_COMMENT', '덧글 달기');
@define('NO_ENTRIES_TO_PRINT', '출력할 글이 없음');
@define('COMMENTS', '덧글');
@define('ADD_COMMENT', '덧글 추가');
@define('NO_COMMENTS', '덧글 없음');
@define('POSTED_BY', '작성자:');
@define('ON', ':');
@define('A_NEW_COMMENT_BLAHBLAH', '당신의 블로그 "%s"에 있는 "%s"(이)라는 글에 새로운 덧글이 달렸습니다.');
@define('A_NEW_TRACKBACK_BLAHBLAH', '"%s"(이)라는 글에 새로운 트랙백이 생성되었습니다.');
@define('NO_CATEGORY', '범주 없음');
@define('ENTRY_BODY', '본문');
@define('EXTENDED_BODY', '추가 내용');
@define('CATEGORY', '범주');
@define('EDIT', '편집');
@define('NO_ENTRIES_BLAHBLAH', '검색어 %s(으)로 검색된 글이 없습니다' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', '검색어 %s(으)로 %s개의 글이 검색되었습니다:');
@define('SEARCH_TOO_SHORT', '검색어는 3자 이상이어야 합니다. 짧은 단어에는 s9y* 식으로 끝에 *을 붙여서 편법으로 검색을 시도해볼 수 있습니다.');
@define('IMAGE', '그림');
@define('ERROR_FILE_NOT_EXISTS', '오류: 예전 파일 이름이 존재하지 않습니다.');
@define('ERROR_FILE_EXISTS', '오류: 새 파일 이름이 이미 사용중이므로 다른 이름으로 지으십시오.');
@define('ERROR_SOMETHING', '오류: 무언가 잘못되었습니다.');
@define('ADDING_IMAGE', '그림 추가중...');
@define('THUMB_CREATED_DONE', '작은 그림이 생성되었습니다.<br/>완료.');
@define('ERROR_FILE_EXISTS_ALREADY', '오류: 파일이 이미 존재합니다.');
@define('ERROR_UNKNOWN_NOUPLOAD', '알 수 없는 오류가 발생하여 파일이 업로드되지 않았습니다. 서버가 허용하는 파일 크기를 초과했을 수 있습니다. 호스팅 업체에 확인을 하거나 php.ini 파일을 수정하여 더 큰 파일을 업로드할 수 있도록 하십시오.');
@define('GO', '시작!');
@define('NEWSIZE', '새로운 크기: ');
@define('RESIZE_BLAHBLAH', '<b>크기 조절: %s</b><p>');
@define('ORIGINAL_SIZE', '원래 크기: <i>%sx%s</i> 픽셀');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>여기서 그림 크기를 조절할 수 있습니다. 비율을 유지하면서 크기를 조절하려면 입력상자 한 쪽에 값을 넣고 Tab 키를 누르면 됩니다. 비율이 유지되는 값이 자동으로 계산됩니다.</p>');
@define('QUICKJUMP_CALENDAR', '빨리 찾아보는 달력');
@define('QUICKSEARCH', '빠른 검색');
@define('SEARCH_FOR_ENTRY', '원하는 글 찾기');
@define('ARCHIVES', '글 목록');
@define('BROWSE_ARCHIVES', '월 단위로 글 보기');
@define('TOP_REFERRER', '상위 진입 링크');
@define('SHOWS_TOP_SITES', '블로그로 가장 자주 링크를 건 사이트 보기');
@define('TOP_EXITS', '상위 진출 링크');
@define('SHOWS_TOP_EXIT', '블로그에서 가장 자주 타고 나간 링크 보기');
@define('SYNDICATION', '배급');
@define('SHOWS_RSS_BLAHBLAH', 'RSS 배급 링크 보여주기');
@define('ADVERTISES_BLAHBLAH', '블로그의 제작 도구를 광고함');
@define('HTML_NUGGET', 'HTML 덩어리');
@define('HOLDS_A_BLAHBLAH', '옆줄에 HTML이 들어있는 덩어리를 넣기');
@define('TITLE_FOR_NUGGET', '덩어리 제목');
@define('THE_NUGGET', 'HTML 덩어리를 넣으세요!');
@define('SYNDICATE_THIS_BLOG', '블로그 배급받기');
@define('YOU_CHOSE', '%s(을)를 골랐습니다');
@define('IMAGE_ROTATE_LEFT', '시계 반대방향으로 90도 회전하기');
@define('IMAGE_ROTATE_RIGHT', '시계 방향으로 90도 회전하기');
@define('IMAGE_SIZE', '그림 크기');
@define('IMAGE_AS_A_LINK', '그림 삽입');
@define('POWERED_BY', '제작 도구');
@define('TRACKBACKS', '트랙백');
@define('TRACKBACK', '트랙백');
@define('NO_TRACKBACKS', '트랙백 없음');
@define('TOPICS_OF', '주제로 본');
@define('VIEW_FULL', '전체 보기');
@define('VIEW_TOPICS', '주제 보기');
@define('AT', '입력:');
@define('SET_AS_TEMPLATE', '템플릿으로 지정하기');
@define('IN', '범주:');
@define('EXCERPT', '발췌');
@define('TRACKED', '추적됨');
@define('LINK_TO_ENTRY', '글에 대한 링크');
@define('LINK_TO_REMOTE_ENTRY', '먼 글에 대한 링크');
@define('IP_ADDRESS', 'IP 주소');
@define('USER', '사용자');
@define('THUMBNAIL_USING_OWN', '%s(은)는 이미 충분히 작으므로 그 자체가 작은 그림으로도 사용됩니다.');
@define('THUMBNAIL_FAILED_COPY', '%s 자체를 작은 그림으로 사용하려고 했으나 복사에 실패했습니다.');
@define('AUTHOR', '작성자');
@define('LAST_UPDATED', '최종 업데이트');
@define('TRACKBACK_SPECIFIC', '이 글에 대한 트랙백 전용 URI');
@define('DIRECT_LINK', '이 글에 대한 직접 링크');
@define('COMMENT_ADDED', '덧글이 성공적으로 달렸습니다. ');
@define('COMMENT_ADDED_CLICK', '%s여기를 눌러%s 덧글 목록으로 돌아가거나 %s여기를 눌러%s 이 창을 닫습니다.');
@define('COMMENT_NOT_ADDED_CLICK', '%s여기를 눌러%s 덧글 목록으로 돌아가거나 %s여기를 눌러%s 이 창을 닫습니다.');
@define('COMMENTS_DISABLE', '이 글에 덧글을 금지하기');
@define('COMMENTS_ENABLE', '이 글에 덧글을 허용하기');
@define('COMMENTS_CLOSED', '작성자가 이 글에 덧글을 금지했습니다');
@define('EMPTY_COMMENT', '덧글 내용이 비어 있으므로 %s돌아가서%s 다시 작성하십시오');
@define('ENTRIES_FOR', '%s: 작성된 글');
@define('DOCUMENT_NOT_FOUND', '%s라는 문서를 찾지 못했습니다.');
@define('USERNAME', '아이디');
@define('PASSWORD', '암호');
@define('AUTOMATIC_LOGIN', '정보 저장');
@define('SERENDIPITY_INSTALLATION', '세렌디피티 설치');
@define('LEFT', '왼쪽');
@define('RIGHT', '오른쪽');
@define('HIDDEN', '숨김');
@define('REMOVE_TICKED_PLUGINS', '선택한 플러그인 제거하기');
@define('SAVE_CHANGES_TO_LAYOUT', '구성 변경을 저장하기');
@define('COMMENTS_FROM', '다음에서 온 덧글:');
@define('ERROR', '오류');
@define('ENTRY_SAVED', '글이 저장되었습니다');
@define('DELETE_SURE', '%s번을 영구적으로 삭제하시겠습니까?');
@define('NOT_REALLY', '아니오');
@define('DUMP_IT', '예');
@define('RIP_ENTRY', '%s번 글이 삭제되었습니다.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', '%s번 범주가 삭제되었습니다. 여기에 속한 글은 %s번 범주로 이동되었습니다.');
@define('CATEGORY_DELETED', '%s번 범주가 삭제되었습니다.');
@define('INVALID_CATEGORY', '삭제할 범주가 지정되지 않았습니다');
@define('CATEGORY_SAVED', '범주가 저장되었습니다');
@define('SELECT_TEMPLATE', '블로그에 사용할 템플릿을 선택하십시오.');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', '글이 성공적으로 삽입되지 않았습니다.');
@define('MT_DATA_FILE', '이동 가능 형태의 데이터 파일');
@define('FORCE', '강제로');
@define('CREATE_AUTHOR', '작성자 \'%s\'(을)를 생성합니다.');
@define('CREATE_CATEGORY', '범주 \'%s\'(을)를 생성합니다.');
@define('MYSQL_REQUIRED', '이 기능을 수행하려면 MySQL 확장기능이 설치되어 있어야 합니다.');
@define('COULDNT_CONNECT', 'MySQL 데이터베이스 \'%s\'에 접속하지 못했습니다.');
@define('COULDNT_SELECT_DB', '데이터베이스 \'%s\'(을)를 선택하지 못했습니다.');
@define('COULDNT_SELECT_USER_INFO', '사용자 정보 \'%s\'(을)를 선택하지 못했습니다.');
@define('COULDNT_SELECT_CATEGORY_INFO', '범주 정보 \'%s\'(을)를 선택하지 못했습니다.');
@define('COULDNT_SELECT_ENTRY_INFO', '작성 글 정보 \'%s\'(을)를 선택하지 못했습니다.');
@define('COULDNT_SELECT_COMMENT_INFO', '덧글 정보 \'%s\'(을)를 선택하지 못했습니다.');
@define('YES', '예');
@define('NO', '아니오');
@define('USE_DEFAULT', '기본값');
@define('CHECK_N_SAVE', '확인 및 저장');
@define('DIRECTORY_WRITE_ERROR', '디렉토리 %s에 기록할 수 없습니다. 권한 설정을 확인하십시오.');
@define('DIRECTORY_CREATE_ERROR', '디렉토리 %s(이)가 존재하지 않으며 생성할 수 없습니다. 직접 디렉토리를 생성해 주십시오');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; 실행: <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', '바이너리 파일 %s(을)를 실행할 수 없습니다');
@define('FILE_WRITE_ERROR', '파일 %s에 기록할 수 없습니다.');
@define('FILE_CREATE_YOURSELF', '파일을 직접 생성하거나 권한 설정을 확인하십시오');
@define('COPY_CODE_BELOW', '<br />* 아래의 코드를 복사하여 %s에 넣고 %s 폴더에 두십시오:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'www를 아파치가 사용하는 사용자 이름(nobody 등)으로 변경하십시오.');
@define('BROWSER_RELOAD', '작업이 끝난 후 브라우저의 "새로고침" 버튼을 누르십시오.');
@define('DIAGNOSTIC_ERROR', '입력한 정보에 검사를 수행하는 도중 에러를 발견했습니다:');
@define('SERENDIPITY_NOT_INSTALLED', '세렌디피티가 아직 설치되지 않았습니다. 지금 <a href="%s">설치</a>하십시오.');
@define('INCLUDE_ERROR', '세렌디피티 오류: %s(을)를 포함시킬 수 없었습니다 - 종료합니다.');
@define('DATABASE_ERROR', '세렌디피티 오류: 데이터베이스에 접속할 수 없었습니다 - 종료합니다.');
@define('CREATE_DATABASE', '기본 데이터베이스 설정 생성중...');
@define('ATTEMPT_WRITE_FILE', '파일 %s에 기록 시도중...');
@define('WRITTEN_N_SAVED', '설정이 기록 및 저장되었습니다');
@define('IMAGE_ALIGNMENT', '그림 정렬');
@define('ENTER_NEW_NAME', '다음에 대해 새 이름을 입력하십시오: ');
@define('RESIZING', '크기 조절중');
@define('RESIZE_DONE', '완료 (%s개의 그림의 크기를 조절함).');
@define('SYNCING', '데이터베이스를 그림 폴더와 동기화합니다');
@define('SYNC_DONE', '완료 (%s개의 그림을 동기화함).');
@define('FILE_NOT_FOUND', '<b>%s</b>라는 이름의 파일을 찾지 못했습니다. 이미 삭제되었을 수 있습니다.');
@define('ABORT_NOW', '지금 중지');
@define('REMOTE_FILE_NOT_FOUND', '원격 서버에서 파일을 찾지 못했습니다. <b>%s</b> (이)라는 주소가 정확합니까?');
@define('FILE_FETCHED', '%s(을)를 %s(으)로 가져옴');
@define('FILE_UPLOADED', '파일 %s(이)가 %s(으)로 성공적으로 업로드되었습니다');
@define('WORD_OR', '또는');
@define('SCALING_IMAGE', '%s(을)를 %s x %s 픽셀 크기로 조절');
@define('KEEP_PROPORTIONS', '비율 유지');
@define('REALLY_SCALE_IMAGE', '크기 조절을 정말로 하겠습니까? 나중에 되돌릴 수 없습니다.');
@define('TOGGLE_ALL', '모두 보기 선택');
@define('TOGGLE_OPTION', '선택 옵션');
@define('SUBSCRIBE_TO_THIS_ENTRY', '이 글을 구독하기');
@define('UNSUBSCRIBE_OK', "%s(은)는 이 글에서 구독 해지가 되었습니다");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', '구독한 글 "%s"에 새로운 덧글이 달림');
@define('SUBSCRIPTION_MAIL', "%s님 안녕하십니까?\n\n\"%s\"에서 구독중인 \"%s\"(이)라는 글에 새로운 덧글이 달렸습니다.\n작성자 이름은 %s 입니다.\n\n여기로 가면 글을 볼 수 있습니다: %s\n\n이 링크를 누르면 구독 해지를 할 수 있습니다: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "%s님 안녕하십니까?\n\n\"%s\"에서 구독중인 \"%s\"(이)라는 글에 새로운 트랙백이 달렸습니다.\n작성자 이름은 %s 입니다.\n\n여기로 가면 글을 볼 수 있습니다: %s\n\n이 링크를 누르면 구독 해지를 할 수 있습니다: %s\n");
@define('SIGNATURE', "\n-- \n%s(은)는 세렌디피티로 작성되었습니다.\n여려분도 쓸 수 있는 최고의 블로그!\n<http://s9y.org>에서 알아보세요.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 피드');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 피드');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 피드');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 덧글');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 피드');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', '"managingEditor" 필드');
@define('SYNDICATION_PLUGIN_WEBMASTER',  '"webMaster" 필드');
@define('SYNDICATION_PLUGIN_BANNERURL', 'RSS 피드를 위한 그림 파일');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', '그림 폭');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', '그림 높이');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  '웹마스터의 전자우편 주소 (빈 상태: 숨김) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', '편집인의 전자우편 주소 (빈 상태: 숨김) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'GIF/JPEG/PNG로 된 그림 파일의 주소 (빈 상태: 세렌디피티 로고 그림)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', '픽셀 단위 (최고 144)');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', '픽셀 단위 (최고 400)');
@define('SYNDICATION_PLUGIN_TTL', '"ttl" 필드 (생존시간)');
@define('SYNDICATION_PLUGIN_TTL_DESC', '외부 사이트 또는 프로그램에 의해서 더 이상 저장되지 않을 시점을 분 단위로 입력 (빈 상태: 숨김) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', '"pubDate" 필드');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'RSS 채널에 "pubDate" 필드를 넣어서 최신으로 올라온 글의 날짜를 보여주겠습니까?');
@define('CONTENT', '내용');
@define('TYPE', '종류');
@define('DRAFT', '초안');
@define('PUBLISH', '게시');
@define('PREVIEW', '미리보기');
@define('DATE', '날짜');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', '경고: 날짜 형태가 유효하지 않습니다. YYYY-MM-DD HH:MM 형태여야 합니다.');
@define('CATEGORY_PLUGIN_DESC', '범주 목록을 보여줍니다.');
@define('ALL_AUTHORS', '모든 작성자');
@define('CATEGORIES_TO_FETCH', '불러올 범주');
@define('CATEGORIES_TO_FETCH_DESC', '어느 작성자에서 범주를 불러오겠습니까?');
@define('PAGE_BROWSE_ENTRIES', '%s번째 페이지 | 총 %s 페이지 | 총 %s개의 글');
@define('PREVIOUS_PAGE', '이전 페이지');
@define('NEXT_PAGE', '다음 페이지');
@define('ALL_CATEGORIES', '모든 범주');
@define('DO_MARKUP', '마크업 변환을 수행합니다');
@define('GENERAL_PLUGIN_DATEFORMAT', '날짜 형태');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'PHP의 strftime() 변수를 통해 글의 작성 날짜 형태를 표현합니다. (기본값: "%s")');
@define('ERROR_TEMPLATE_FILE', '템플릿 파일을 열지 못했습니다. 세렌디피티를 업데이트 하십시오.');
@define('ADVANCED_OPTIONS', '고급 옵션');
@define('EDIT_ENTRY', '글 편집');
@define('HTACCESS_ERROR', '웹서버 설치 상태를 확인하십시오. 세렌디피티는 ".htaccess" 파일에 기록을 할 수 있어야 하지만 권한 설정 오류 때문에 기록을 할 수 없었습니다. 다음과 같이 권한 설정을 바꾸십시오: <br />&nbsp;&nbsp;%s<br /> 그리고 이 페이지를 다시 여십시오.');
@define('SIDEBAR_PLUGINS', '옆줄 플러그인');
@define('EVENT_PLUGINS', '이벤트 플러그인');
@define('SORT_ORDER', '정렬 순서');
@define('SORT_ORDER_NAME', '파일 이름');
@define('SORT_ORDER_EXTENSION', '파일 확장자');
@define('SORT_ORDER_SIZE', '파일 크기');
@define('SORT_ORDER_WIDTH', '그림 폭');
@define('SORT_ORDER_HEIGHT', '그림 높이');
@define('SORT_ORDER_DATE', '업로드 시간');
@define('SORT_ORDER_ASC', '오름차');
@define('SORT_ORDER_DESC', '내림차');
@define('THUMBNAIL_SHORT', '작은 그림');
@define('ORIGINAL_SHORT', '원래 그림');
@define('APPLY_MARKUP_TO', '%s에 마크업 적용');
@define('CALENDAR_BEGINNING_OF_WEEK', '한 주의 시작점');
@define('SERENDIPITY_NEEDS_UPGRADE', '세렌디피티 현재 설치 버전이 %s인 것으로 나타났습니다. 버전 %s로 업그레이드를 계속 진행하려면 <a href="%s">여기</a>를 누르십시오.');
@define('SERENDIPITY_UPGRADER_WELCOME', '세렌디피티 업그레이드 에이전트에 오신 것을 환영합니다.');
@define('SERENDIPITY_UPGRADER_PURPOSE', '설치된 세렌디피티 %s의 업그레이드를 도와드리겠습니다.');
@define('SERENDIPITY_UPGRADER_WHY', '세렌디피티 %s 설치가 되었으나 이 버전에 맞도록 데이터베이스가 아직 업그레이드 되지 않았기 때문에 이 글을 보고 계십니다.');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', '데이터베이스 업데이트 (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', '세렌디피티가 정상적으로 작동하려면 다음 .sql 파일을 먼저 실행해야 합니다');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  '이 버전에 특화된 작업');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', '이 버전에 특화된 작업이 없습니다');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', '위의 작업을 수행하도록 하겠습니까?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', '아니오 - 수동으로 수행하겠습니다');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', '예 - 수행하십시오');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', '업그레이드할 사항이 없습니다');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', '세렌디피티가 업그레이드 되었습니다');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', '세렌디피티의 업그레이드 단계를 건너뛰었습니다. 데이터베이스가 제대로 설치되었고 스케줄된 기능이 수행되는지 반드시 확인하십시오');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', '세렌디피티가 버전 %s로 업그레이드 되었습니다');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', '%s여기%s를 눌러 블로그로 돌아갈 수 있습니다');
@define('MANAGE_USERS', '사용자 관리');
@define('CREATE_NEW_USER', '새로운 사용자 생성');
@define('CREATE_NOT_AUTHORIZED', '본인과 같은 레벨인 사용자를 변경할 수 없습니다');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', '본인보다 높은 레벨의 사용자를 생성할 수 없습니다');
@define('CREATED_USER', '새로운 사용자 %s(이)가 생성되었습니다');
@define('MODIFIED_USER', '%s의 설정이 변경되었습니다');
@define('USER_LEVEL', '사용자 레벨');
@define('DELETE_USER', '사용자 %d번인 %s(을)를 삭제하게 됩니다. 계속 하시겠습니까? 이 사용자가 작성한 글이 더 이상 일반 페이지에 나타나지 않게 됩니다.');
@define('DELETED_USER', '사용자 %d번인 %s(이)가 삭제되었습니다.');
@define('LIMIT_TO_NUMBER', '몇 개의 아이템을 표시하겠습니까?');
@define('ENTRIES_PER_PAGE', '한 페이지에 표시할 글');
@define('XML_IMAGE_TO_DISPLAY', 'XML 버튼');
@define('XML_IMAGE_TO_DISPLAY_DESC','XML 피드에 이 그림이 나타납니다. 비운 상태면 기본 그림이 보이고 \'none\'을 입력하면 나타나지 않습니다.');

@define('DIRECTORIES_AVAILABLE', '하위 디렉토리 목록에서 디렉토리 이름을 누르면 그 디렉토리 안에 새 디렉토리를 만들 수 있습니다.');
@define('ALL_DIRECTORIES', '모든 디렉토리');
@define('MANAGE_DIRECTORIES', '디렉토리 관리');
@define('DIRECTORY_CREATED', '디렉토리 <strong>%s</strong>(이)가 생성되었습니다.');
@define('PARENT_DIRECTORY', '상위 디렉토리');
@define('CONFIRM_DELETE_DIRECTORY', '디렉토리 %s에 포함된 모든 내용을 삭제하겠습니까?');
@define('ERROR_NO_DIRECTORY', '오류: 디렉토리 %s(이)가 존재하지 않습니다');
@define('CHECKING_DIRECTORY', '디렉토리 %s 내의 파일 점검중');
@define('DELETING_FILE', '파일 %s 삭제중...');
@define('ERROR_DIRECTORY_NOT_EMPTY', '비어 있지 않은 디렉토리를 삭제할 수 없습니다. 남아있는 파일도 제거하려면 "강제 삭제"를 체크하고 다시 시도하십시오. 남아있는 파일은:');
@define('DIRECTORY_DELETE_FAILED', '디렉토리 %s 삭제에 실패했습니다. 권한 설정이나 위의 메시지를 확인하십시오.');
@define('DIRECTORY_DELETE_SUCCESS', '디렉토리 %s(이)가 성공적으로 삭제되었습니다.');
@define('SKIPPING_FILE_EXTENSION', '파일 건너뜀: %s에 확장자가 없음.');
@define('SKIPPING_FILE_UNREADABLE', '파일 건너뜀: %s(을)를 읽을 수 없음.');
@define('FOUND_FILE', '새 파일 또는 수정된 파일 발견: %s.');
@define('ALREADY_SUBCATEGORY', '%s(은)는 이미 %s의 하위 범주입니다.');
@define('PARENT_CATEGORY', '상위 범주');
@define('IN_REPLY_TO', '답글 대상:');
@define('TOP_LEVEL', '최상위 (본문)');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s 피드');
@define('PERMISSIONS', '권한 설정');
@define('SETTINGS_SAVED_AT', '새로운 설정이 %s에 저장되었습니다');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', '데이터베이스 설정');
@define('INSTALL_CAT_DB_DESC', '데이터베이스 정보를 모두 입력하십시오. 세렌디피티가 정상 작동을 하기 위해 필요합니다.');
@define('INSTALL_DBTYPE', '데이터베이스 종류');
@define('INSTALL_DBTYPE_DESC', '데이터베이스 종류');
@define('INSTALL_DBHOST', '데이터베이스 호스트');
@define('INSTALL_DBHOST_DESC', '데이터베이스 서버의 호스트네임');
@define('INSTALL_DBUSER', '데이터베이스 사용자');
@define('INSTALL_DBUSER_DESC', '데이터베이스에 접속하기 위한 사용자 이름');
@define('INSTALL_DBPASS', '데이터베이스 암호');
@define('INSTALL_DBPASS_DESC', '사용자 이름에 대응하는 암호');
@define('INSTALL_DBNAME', '데이터베이스 이름');
@define('INSTALL_DBNAME_DESC', '사용할 데이터베이스의 이름');
@define('INSTALL_DBPREFIX', '데이터베이스 테이블 접두사');
@define('INSTALL_DBPREFIX_DESC', '테이블 이름 앞에 붙일 글자 (serendipity_ 식으로)');

/* PATHS */
@define('INSTALL_CAT_PATHS', '경로');
@define('INSTALL_CAT_PATHS_DESC', '필수 디렉토리 및 파일에 대한 경로를 지정합니다. 디렉토리 끝에 슬래시 추가하는 것을 잊지 마십시오.');
@define('INSTALL_FULLPATH', '전체 경로');
@define('INSTALL_FULLPATH_DESC', '세렌디피티 설치 위치의 절대 경로');
@define('INSTALL_UPLOADPATH', '업로드 경로');
@define('INSTALL_UPLOADPATH_DESC', '업로드된 파일이 저장되는 위치로써 \'전체 경로\'에 대한 상대 경로임 - 일반적으로 \'uploads/\'');
@define('INSTALL_RELPATH', '상대 경로');
@define('INSTALL_RELPATH_DESC', '브라우저에 나타날 세렌디피티의 경로임 - 일반적으로 \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', '템플릿 상대 경로');
@define('INSTALL_RELTEMPLPATH_DESC', '템플릿이 저장된 디렉토리의 경로로써 \'상대 경로\'에 대한 상대 경로임');
@define('INSTALL_RELUPLOADPATH', '업로드 상대 경로');
@define('INSTALL_RELUPLOADPATH_DESC', '브라우저에 나타날 업로드 경로로써 \'상대 경로\'에 대한 상대 경로임');
@define('INSTALL_URL', '블로그 주소');
@define('INSTALL_URL_DESC', '세렌디피티 설치가 된 기본 인터넷 주소');
@define('INSTALL_INDEXFILE', '인덱스 파일');
@define('INSTALL_INDEXFILE_DESC', '세렌디피티 인덱스 파일의 이름');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', '일반 설정');
@define('INSTALL_CAT_SETTINGS_DESC', '세렌디피티의 작동 방식을 정합니다.');
@define('INSTALL_USERNAME', '관리자 아이디');
@define('INSTALL_USERNAME_DESC', '관리자 로그인을 위한 아이디');
@define('INSTALL_PASSWORD', '관리자 암호');
@define('INSTALL_PASSWORD_DESC', '관리자 로그인을 위한 암호');
@define('INSTALL_EMAIL', '관리자 전자우편');
@define('INSTALL_EMAIL_DESC', '블로그 관리자의 전자우편 주소');
@define('INSTALL_SENDMAIL', '관리자에게 전자우편 발송');
@define('INSTALL_SENDMAIL_DESC', '작성한 글에 덧글이 달렸을 경우 전자우편을 받겠습니까?');
@define('INSTALL_SUBSCRIBE', '작성한 글에 다른 사용자의 구독을 허용');
@define('INSTALL_SUBSCRIBE_DESC', '작성한 글에 다른 사용자가 구독할 수 있게 함으로써 새로운 덧글이 글에 달리면 전자우편을 받게 함');
@define('INSTALL_BLOGNAME', '블로그 이름');
@define('INSTALL_BLOGNAME_DESC', '블로그에 사용할 제목');
@define('INSTALL_BLOGDESC', '블로그 설명');
@define('INSTALL_BLOGDESC_DESC', '블로그의 내용을 적음');
@define('INSTALL_LANG', '언어');
@define('INSTALL_LANG_DESC', '블로그에 사용할 언어 선택');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', '시각적 요소 및 옵션');
@define('INSTALL_CAT_DISPLAY_DESC', '세렌디피티의 직관적인 모습과 느낌을 정합니다.');
@define('INSTALL_WYSIWYG', 'WYSIWYG 편집기 사용');
@define('INSTALL_WYSIWYG_DESC', 'WYSIWYG 편집기를 사용하겠습니까? (인터넷 익스플로러 5 이상에서 작동, 모질라 1.3 이상에서 부분 작동)');
@define('INSTALL_XHTML11', 'XHTML 1.1 규격을 강제로 따름');
@define('INSTALL_XHTML11_DESC', 'XHTML 1.1 규격을 강제로 따르겠습니까? (오래된 4세대 브라우저에서 문제를 일으킬 수 있음)');
@define('INSTALL_POPUP', '팝업 창을 사용함');
@define('INSTALL_POPUP_DESC', '덧글이나 트랙백 등에 팝업 창을 사용하겠습니까?');
@define('INSTALL_EMBED', '세렌디피티가 내장된 형태입니까?');
@define('INSTALL_EMBED_DESC', '일반 페이지 속에 세렌디피티를 내장시키려면 "예"를 선택하여 헤더가 제외된 내용 부분만 출력시키게 합니다. indexFile 옵션을 사용하여 일반적인 웹페이지 헤더에 wrapper 클래스를 적용할 수 있습니다. 보다 자세한 사항은 README 파일을 참조하십시오.');
@define('INSTALL_TOP_AS_LINKS', '상위 진출/진입 사항을 링크로 표시');
@define('INSTALL_TOP_AS_LINKS_DESC', '"아니오": 구글 스팸을 방지하기 위해 진출 및 진입 사항을 일반 글로 표시합니다. "예": 진출 및 진입 사항에 링크를 겁니다. "기본값": 젠체 설정에 따릅니다(추천).');
@define('INSTALL_BLOCKREF', '진입 표시 통제');
@define('INSTALL_BLOCKREF_DESC', '진입 사항에 표시되지 않았으면 하는 호스트가 있을 경우 각 호스트를 \';\'로 분리해서 입력합니다. 표시 통제는 부분 검색을 사용합니다(지정한 이름이 호스트의 일부일 경우 통제됨).');
@define('INSTALL_REWRITE', '주소 재기록');
@define('INSTALL_REWRITE_DESC', '주소 생성시 사용할 규칙을 정합니다. 재기록 규칙을 활성화시키면 블로그에 대한 주소가 깔끔해지고 구글과 같은 검색엔진에 의해 인덱싱이 잘 됩니다. 웹서버가 세렌디피티 디렉토리에 대해 mod_rewrite나 "AllowOverride All"을 지원해야 합니다. 기본 설정은 자동 검출됩니다.');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', '그림 변환 설정');
@define('INSTALL_CAT_IMAGECONV_DESC', '세렌디피티가 그림을 어떻게 다룰지에 대한 정보를 입력합니다.');
@define('INSTALL_IMAGEMAGICK', 'ImageMagick 사용하기');
@define('INSTALL_IMAGEMAGICK_DESC', 'ImageMagick이 설치되어 있으며 그림 크기를 조절하는데 사용하겠습니까?');
@define('INSTALL_IMAGEMAGICKPATH', '변환 바이너리 경로');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'ImageMagick의 변환 바이너리(프로그램)의 이름 및 전체 경로');
@define('INSTALL_THUMBSUFFIX', '작은 그림 접두사');
@define('INSTALL_THUMBSUFFIX_DESC', '작은 그림은 원래이름.[접두사].확장자 식의 이름으로 생성됩니다');
@define('INSTALL_THUMBWIDTH', '작은 그림 크기');
@define('INSTALL_THUMBWIDTH_DESC', '자동 생성되는 작은 그림의 최대 크기');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', '사용자의 개인 정보');
@define('USERCONF_CAT_PERSONAL_DESC', '개인 정보를 변경하는 곳입니다.');
@define('USERCONF_USERNAME', '아이디');
@define('USERCONF_USERNAME_DESC', '블로그에 로그인하기 위한 사용자 이름');
@define('USERCONF_PASSWORD', '암호');
@define('USERCONF_PASSWORD_DESC', '블로그에 로그인하기 위한 암호');
@define('USERCONF_EMAIL', '전자우편 주소');
@define('USERCONF_EMAIL_DESC', '사용하고 있는 개인 전자우편 주소');
@define('USERCONF_SENDCOMMENTS', '덧글 알림 발송');
@define('USERCONF_SENDCOMMENTS_DESC', '작성된 글에 덧글이 달리면 전자우편을 받겠습니까?');
@define('USERCONF_SENDTRACKBACKS', '트랙백 알림 발송');
@define('USERCONF_SENDTRACKBACKS_DESC', '작성된 글에 트랙백이 추가되면 전자우편을 받겠습니까?');
@define('USERCONF_ALLOWPUBLISH', '글 작성 권한');
@define('USERCONF_ALLOWPUBLISH_DESC', '이 사용자가 글을 작성할 권한이 있습니까?');
@define('SUCCESS', '성공');
@define('POWERED_BY_SHOW_TEXT', '"세렌디피티"를 텍스트로 출력');
@define('POWERED_BY_SHOW_TEXT_DESC', '"세렌디피티 웨블로그"를 텍스트로 출력함');
@define('POWERED_BY_SHOW_IMAGE', '"세렌디피티"를 로고로 출력');
@define('POWERED_BY_SHOW_IMAGE_DESC', '세렌디피티 로고를 보여줌');
@define('PLUGIN_ITEM_DISPLAY', '아이템이 어디에 표시됩니까?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', '추가 내용에만');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', '요약 페이지에만');
@define('PLUGIN_ITEM_DISPLAY_BOTH', '항상 표시');
@define('RSS_IMPORT_CATEGORY', '불러들인 글 중에서 범주가 맞지 않을 경우 이 범주를 사용');

@define('COMMENTS_WILL_BE_MODERATED', '입력된 덧글은 표시가 되기 전에 검토를 거치게 됩니다.');
@define('YOU_HAVE_THESE_OPTIONS', '다음과 같은 옵션을 사용할 수 있습니다:');
@define('THIS_COMMENT_NEEDS_REVIEW', '경고: 이 덧글은 표시가 되기 전에 승인을 받아야 합니다');
@define('DELETE_COMMENT', '덧글 삭제');
@define('APPROVE_COMMENT', '덧글 승인');
@define('REQUIRES_REVIEW', '검토 필요');
@define('COMMENT_APPROVED', '%s번 덧글이 성공적으로 승인되었습니다.');
@define('COMMENT_DELETED', '%s번 덧글이 성공적으로 삭제되었습니다.');
@define('COMMENTS_MODERATE', '이 글에 대한 덧글 및 트랙백은 검토를 거치게 됨');
@define('THIS_TRACKBACK_NEEDS_REVIEW', '경고: 이 트랙백은 표시가 되기 전에 승인을 받아야 합니다');
@define('DELETE_TRACKBACK', '트랙백 삭제');
@define('APPROVE_TRACKBACK', '트랙백 승인');
@define('TRACKBACK_APPROVED', '%s번 트랙백이 성공적으로 승인되었습니다.');
@define('TRACKBACK_DELETED', '%s번 트랙백이 성공적으로 삭제되었습니다.');
@define('VIEW', '보기');
@define('COMMENT_ALREADY_APPROVED', '%s번 덧글은 이미 승인받은 것으로 나타났습니다.');
@define('COMMENT_EDITED', '선택된 덧글이 편집되었습니다.');
@define('HIDE', '숨기기');
@define('VIEW_EXTENDED_ENTRY', '"%s" 계속 읽기');
@define('TRACKBACK_SPECIFIC_ON_CLICK', '이 링크는 클릭하기 위한 것이 아닙니다. 본문의 트랙백 URI을 담고 있습니다. 이 URI을 통해서 여러분의 블로그에서 이 블로그로 핑 및 트랙백을 보낼 수 있습니다. 링크를 복사하려면 오른쪽 클릭을 한 뒤 인터넷 익스플로러에서는 "바로가기 복사"를, 모질라에서는 "링크 위치 복사"를 선택하십시오.');
@define('PLUGIN_SUPERUSER_HTTPS', '로그인에 https 사용');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', '로그인 링크가 https 위치로 향하도록 합니다. 웹서버가 이 기능을 지원해야 합니다.');
@define('INSTALL_SHOW_EXTERNAL_LINKS', '외부 링크를 클릭할 수 있게 하기');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"아니오": 확인되지 않은 외부 링크(상위 진출, 상위 진입, 사용자 덧글)는 보여지지 않거나 일반 텍스트로 표시되어 구글 스팸을 방지합니다(추천). "예": 확인되지 않은 외부 링크가 하이퍼링크로 걸립니다. 옆줄 플러그인 설정에서 별도로 정할 수 있습니다.');
@define('PAGE_BROWSE_COMMENTS', '%s번째 페이지 | 총 %s 페이지 | 총 %s개 덧글');
@define('FILTERS', '필터');
@define('FIND_ENTRIES', '글 찾기');
@define('FIND_COMMENTS', '덧글 찾기');
@define('FIND_MEDIA', '미디어 찾기');
@define('FILTER_DIRECTORY', '디렉토리');
@define('SORT_BY', '정렬 순서');
@define('TRACKBACK_COULD_NOT_CONNECT', '트랙백이 보내지지 않음: %s에 대해서 포트 %d에서 열 수 없었음');
@define('MEDIA', '미디어');
@define('MEDIA_LIBRARY', '미디어 보관함');
@define('ADD_MEDIA', '미디어 추가');
@define('ENTER_MEDIA_URL', '불러올 파일의 인터넷 주소를 입력:');
@define('ENTER_MEDIA_UPLOAD', '업로드할 파일 선택:');
@define('SAVE_FILE_AS', '저장할 파일 이름 지정:');
@define('STORE_IN_DIRECTORY', '저장할 디렉토리 지정: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>미디어 보관함에 파일 추가:</b><p>여기서 미디어 파일을 업로드하거나 인터넷에서 파일을 불러올 수 있습니다. 적당한 그림을 가지고 있지 않으면 생각이 떠오른 대로 <a href="http://images.google.com" target="_blank">구글에서 그림을 검색</a>해보면 유용하고 재미있습니다. 단, 대부분의 그림은 저작권이 설정되어 있으므로 사용하기 전에 허락을 받는 것에 유의하십시오.</p><p><b>방법 선택:</b></p><br/>');
@define('MEDIA_RENAME', '파일 이름 변경');
@define('IMAGE_RESIZE', '그림 크기 조절');
@define('MEDIA_DELETE', '파일 삭제');
@define('FILES_PER_PAGE', '페이지 당 파일 개수');
@define('CLICK_FILE_TO_INSERT', '삽입할 파일을 누르십시오:');
@define('SELECT_FILE', '삽입할 파일 선택');
@define('MEDIA_FULLSIZE', '최대 크기');
@define('CALENDAR_BOW_DESC', '한 주일의 시작으로 간주할 요일을 선택합니다. 기본값은 월요일입니다.');
@define('SUPERUSER', '블로그 관리');
@define('ALLOWS_YOU_BLAHBLAH', '블로그 관리를 하기 위한 링크를 옆줄에 표시합니다.');
@define('CALENDAR', '달력');
@define('SUPERUSER_OPEN_ADMIN', '관리 화면 열기');
@define('SUPERUSER_OPEN_LOGIN', '로그인 화면 열기');
@define('INVERT_SELECTIONS', '선택 반전');
@define('COMMENTS_DELETE_CONFIRM', '선택한 덧글을 정말로 삭제하겠습니까?');
@define('COMMENT_DELETE_CONFIRM', '%d번 덧글 (작성자: %s) 삭제를 정말로 하겠습니까?');
@define('DELETE_SELECTED_COMMENTS', '선택한 덧글 삭제');
@define('VIEW_COMMENT', '덧글 보기');
@define('VIEW_ENTRY', '본문 보기');
@define('DELETE_FILE_FAIL' , '파일 <b>%s</b> 삭제 실패');
@define('DELETE_THUMBNAIL', '작은 그림 <b>%s</b> 삭제됨');
@define('DELETE_FILE', '파일 <b>%s</b> 삭제됨');
@define('ABOUT_TO_DELETE_FILE', '<b>%s</b> 삭제를 하려고 합니다.<br />작성한 글에서 이 파일을 사용하고 있을 경우 링크나 그림이 깨질 수 있습니다.<br />계속 하겠습니까?<br /><br />');
@define('TRACKBACK_SENDING', '트랙백을 URI %s(으)로 보내는 중...');
@define('TRACKBACK_SENT', '트랙백 성공');
@define('TRACKBACK_FAILED', '트랙백 실패: %s');
@define('TRACKBACK_NOT_FOUND', '트랙백 URI를 찾지 못했습니다.');
@define('TRACKBACK_URI_MISMATCH', '자동 검색된 트랙백 URI는 목표 URI와 맞지 않습니다.');
@define('TRACKBACK_CHECKING', '트랙백이 있는지 <u>%s</u> 확인중...');
@define('TRACKBACK_NO_DATA', '목표가 데이터를 담고 있지 않습니다.');
@define('TRACKBACK_SIZE', '목표 URI가 최개 파일 크기인 %s 바이트를 초과합니다.');
@define('COMMENTS_VIEWMODE_THREADED', '엮은 형태');
@define('COMMENTS_VIEWMODE_LINEAR', '나열 형태');
@define('DISPLAY_COMMENTS_AS', '덧글 표시 방식:');
@define('COMMENTS_FILTER_SHOW', '보이기');
@define('COMMENTS_FILTER_ALL', '전체');
@define('COMMENTS_FILTER_APPROVED_ONLY', '승인된 것만');
@define('COMMENTS_FILTER_NEED_APPROVAL', '승인 검토중');
@define('RSS_IMPORT_BODYONLY', '불러들인 텍스트를 모두 "본문" 부분에 넣고 "추가 내용" 부분에 분리해서 넣지 않습니다.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'RSS 피드 안에 추가 내용을 포함한 글 전체를 보임');
@define('WEEK', '주');
@define('WEEKS', '주');
@define('MONTHS', '월');
@define('DAYS', '일');
@define('ARCHIVE_FREQUENCY', '표시 아이템의 주기');
@define('ARCHIVE_FREQUENCY_DESC', '목록에 있는 각 아이템의 달력 상의 주기 단위');
@define('ARCHIVE_COUNT', '목록에 표시될 아이템 수');
@define('ARCHIVE_COUNT_DESC', '표시할 달, 주, 또는 날의 총 개수');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', '설치된 플러그인의 목록입니다.');
@define('SIDEBAR_PLUGIN', '옆줄 플러그인');
@define('EVENT_PLUGIN', '이벤트 플러그인');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', '새로운 %s 설치하기');
@define('VERSION', '버전');
@define('INSTALL', '설치하기');
@define('ALREADY_INSTALLED', '이미 설치됨');
@define('SELECT_A_PLUGIN_TO_ADD', '설치하고 싶은 플러그인을 선택하십시오.');
@define('INSTALL_OFFSET', '서버 시간과의 시간 차이');
@define('STICKY_POSTINGS', '꼭대기에 표시할 글');
@define('INSTALL_FETCHLIMIT', '한 페이지에 표시할 글 수');
@define('INSTALL_FETCHLIMIT_DESC', '일반 페이지 각각에 표시할 글의 수');
@define('IMPORT_ENTRIES', '데이터 불러오기');
@define('EXPORT_ENTRIES', '글 내보내기');
@define('IMPORT_WELCOME', '세렌디피티의 데이터 불러오기 유틸리티입니다');
@define('IMPORT_WHAT_CAN', '다른 블로그 소프트웨어로 작성된 글을 여기서 불러들일 수 있습니다');
@define('IMPORT_SELECT', '불러들일 글의 소프트웨어 종류를 고르십시오');
@define('IMPORT_PLEASE_ENTER', '아래에 안내하는 대로 데이터를 입력하십시오');
@define('IMPORT_NOW', '불러들이기 시작!');
@define('IMPORT_STARTING', '불러들이기 과정을 시작합니다...');
@define('IMPORT_FAILED', '불러들이기 실패');
@define('IMPORT_DONE', '불러들이기 성공');
@define('IMPORT_WEBLOG_APP', '블로그 소프트웨어');
@define('IMPORT_NOTES', '주의:');
@define('EXPORT_FEED', 'RSS 피드 전체로 내보내기');
@define('STATUS', '불러들이기 후 상태');
@define('IMPORT_GENERIC_RSS', '일반 RSS 불러들이기');
@define('ACTIVATE_AUTODISCOVERY', '글 속에 발견된 링크로 트랙백을 보냄');
@define('WELCOME_TO_ADMIN', '세렌디피티 관리 도구에 오신 것을 환영합니다.');
@define('PLEASE_ENTER_CREDENTIALS', '인증 정보를 아래에 입력하십시오.');
@define('ADMIN_FOOTER_POWERED_BY', '세렌디피티 %s 및 PHP %s로 작성되었습니다.');
@define('INSTALL_USEGZIP', 'Gzip 압축 페이지 사용');
@define('INSTALL_USEGZIP_DESC', '페이지 전송 속도를 향상시키기 위해, 사용자의 브라우저가 기능 지원을 할 경우 페이지를 압축해서 전송할 수 있습니다. 추천 사항입니다.');
@define('INSTALL_SHOWFUTURE', '미래에 작성한 글 보이기');
@define('INSTALL_SHOWFUTURE_DESC', '이 기능을 사용할 경우 작성 날짜가 미래인 글도 모두 블로그에 표시하게 됩니다. 기본값은 이러한 글을 작성 날짜가 다다를 때까지 숨기는 것입니다.');
@define('INSTALL_DBPERSISTENT', '지속적인 접속 사용');
@define('INSTALL_DBPERSISTENT_DESC', '지속적으로 데이터페이스에 접속하는 기능을 사용합니다. <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">여기에서</a> 자세한 정보를 읽을 수 있습니다. 일반적으로 비추천 사항입니다.');
@define('NO_IMAGES_FOUND', '그림이 없습니다');
@define('PERSONAL_SETTINGS', '개인 설정');
@define('REFERER', '진입 경로');
@define('NOT_FOUND', '찾지 못함');
@define('WRITABLE', '쓰기 가능');
@define('NOT_WRITABLE', '쓰기 불가');
@define('PROBLEM_DIAGNOSTIC', '점검 결과 문제가 발견되어 위에 지적된 오류를 수정하기 전까지 설치를 진행할 수 없습니다.');
@define('SELECT_INSTALLATION_TYPE', '설치 방식을 고르십시오');
@define('WELCOME_TO_INSTALLATION', '세렌디피티 설치과정에 오신 것을 환영합니다.');
@define('FIRST_WE_TAKE_A_LOOK', '먼저 현재 설정 상태를 확인하고 호환성 문제가 있는지 점검하겠습니다.');
@define('ERRORS_ARE_DISPLAYED_IN', '오류 사항은 %s으로, 추천 사항은 %s으로, 성공 사항은 %s으로 표시됩니다.');
@define('RED', '빨강색');
@define('YELLOW', '노랑색');
@define('GREEN', '초록색');
@define('PRE_INSTALLATION_REPORT', '세렌디피티 v%s 설치 준비 보고서');
@define('RECOMMENDED', '추천 설정');
@define('ACTUAL', '실제 설정');
@define('PHPINI_CONFIGURATION', 'php.ini 설정');
@define('PHP_INSTALLATION', 'PHP 설치 상태');
@define('THEY_DO', '그러함');
@define('THEY_DONT', '그렇지 않음');
@define('SIMPLE_INSTALLATION', '간단한 설치');
@define('EXPERT_INSTALLATION', '전문가 설치');
@define('COMPLETE_INSTALLATION', '설치 끝내기');
@define('WONT_INSTALL_DB_AGAIN', '데이터베이스를 다시 설치하지 않습니다');
@define('CHECK_DATABASE_EXISTS', '데이터베이스 및 테이블이 이미 존재하는지 확인합니다');
@define('CREATING_PRIMARY_AUTHOR', '기본 작성자 \'%s\' 생성중');
@define('SETTING_DEFAULT_TEMPLATE', '기본 템플릿 설정중');
@define('INSTALLING_DEFAULT_PLUGINS', '기본 플러그인 설치중');
@define('SERENDIPITY_INSTALLED', '세렌디피티가 성공적으로 설치되었습니다');
@define('VISIT_BLOG_HERE', '새로 만들어진 블로그로 가기');
@define('THANK_YOU_FOR_CHOOSING', '세렌디피티를 선택해주셔서 감사합니다');
@define('ERROR_DETECTED_IN_INSTALL', '설치 도중 오류가 발생했습니다');
@define('OPERATING_SYSTEM', '운영체제');
@define('WEBSERVER_SAPI', '웹서버 SAPI');
@define('TEMPLATE_SET', '\'%s\'(을)를 사용할 템플릿으로 지정했습니다.');
@define('SEARCH_ERROR', '검색 기능이 예상했던 대로 작동하지 않았습니다. 블로그 관리자에게 알립니다: 이 현상은 데이터베이스 내에 인덱스 키가 빠져있어서 발생할 수 있습니다. MySQL에서 다음 질의를 실행할 수 있는 데이터베이스 사용자 권한이 있어야 합니다: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> 데이터베이스에서 보고한 구체적인 에러는 다음과 같습니다: <pre>%s</pre>');
@define('EDIT_THIS_CAT', '"%s" 편집');
@define('CATEGORY_REMAINING', '이 범주를 삭제하고 여기에 속한 글을 이 범주로 옮김');
@define('CATEGORY_INDEX', '글에 적용할 수 있는 범주 목록입니다');
@define('NO_CATEGORIES', '범주 없음');
@define('RESET_DATE', '날짜 재설정');
@define('RESET_DATE_DESC', '현재 시간으로 날짜를 재설정하려면 여기를 누르십시오');
@define('PROBLEM_PERMISSIONS_HOWTO', '권한 설정은 문제가 발생한 디렉토리에 대해 쉘 명령어 `<em>%s</em>`를 실행하거나 FTP 프로그램을 통해 이를 설정함으로써 바로잡을 수 있습니다.');
@define('WARNING_TEMPLATE_DEPRECATED', '경고: 사용중인 템플릿이 구식 템플릿 방식을 사용하고 있습니다. 가능하다면 업데이트 하십시오.');
@define('ENTRY_PUBLISHED_FUTURE', '이 글은 아직 게시되지 않았습니다.');
@define('ENTRIES_BY', '%s에 의한 글');
@define('PREVIOUS', '이전');
@define('NEXT', '다음');
@define('APPROVE', '승인');
@define('DO_MARKUP_DESCRIPTION', '텍스트에 마크업 변환(이모티콘, *, /, _ 등을 활용한 마크업)을 적용합니다. 사용하지 않으면 입력한 HTML 코드가 모두 보존됩니다.');
@define('CATEGORY_ALREADY_EXIST', '"%s"(이)라는 범주가 이미 존재합니다.');
@define('ERROR_FILE_FORBIDDEN', '액티브 컨텐츠가 담긴 파일을 업로드할 수 없습니다.');
@define('ADMIN', '관리 사항');
@define('ADMIN_FRONTPAGE', '기본 페이지');
@define('QUOTE', '인용');
@define('IFRAME_SAVE', '세렌디피티가 글을 저장하면서 트랙백을 생성하고 XML-RPC 호출을 수행하는 중입니다. 약간 시간이 걸릴 수 있습니다.');
@define('IFRAME_SAVE_DRAFT', '이 글의 초안이 저장되었습니다.');
@define('IFRAME_PREVIEW', '세렌디피티가 미리보기를 생성하고 있습니다...');
@define('IFRAME_WARNING', '브라우저가 iframes에 대한 개념을 지원하지 않습니다. serendipity_config.inc.php 파일을 열어서 $serendipity[\'use_iframe\'] 변수를 FALSE로 설정하십시오.');
@define('NONE', '없음');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', '새 글에 대한 기본 설정');
@define('UPGRADE', '업그레이드');
@define('UPGRADE_TO_VERSION', '버전 %s(으)로 업그레이드');
@define('DELETE_DIRECTORY', '디렉토리 삭제');
@define('DELETE_DIRECTORY_DESC', '미디어 파일이 담긴 디렉토리의 내용을 삭제하려고 합니다. 이 파일들은 본문에 사용중일 수 있습니다.');
@define('FORCE_DELETE', '이 디렉토리에 있는 모든 파일 (세렌디피티가 모르는 종류 포함) 삭제');
@define('CREATE_DIRECTORY', '디렉토리 생성');
@define('CREATE_NEW_DIRECTORY', '새 디렉토리 생성');
@define('CREATE_DIRECTORY_DESC', '미디어 파일을 담을 새 디렉토리를 여기서 생성할 수 있습니다. 새 디렉토리의 이름을 정한 다음 디렉토리가 들어갈 상위 디렉토리를 고릅니다.');
@define('BASE_DIRECTORY', '기본 디렉토리');
@define('USERLEVEL_EDITOR_DESC', '일반 편집인');
@define('USERLEVEL_CHIEF_DESC', '수석 편집인');
@define('USERLEVEL_ADMIN_DESC', '관리자');
@define('USERCONF_USERLEVEL', '권한 레벨');
@define('USERCONF_USERLEVEL_DESC', '이 레벨은 블로그에 대해 사용자가 어떤 권한을 가지는지 결정하는데 사용됩니다.');
@define('USER_SELF_INFO', '%s (%s) 로그인 됨');
@define('ADMIN_ENTRIES', '글 관리');
@define('RECHECK_INSTALLATION', '설치 상태 재확인 필요');
@define('IMAGICK_EXEC_ERROR', '실행할 수 없음: "%s", 오류: %s, 리턴 변수: %d');
@define('INSTALL_OFFSET_DESC', '웹서버의 시간(현재: %clock%)과 사용자의 시간대와의 차이를 시간 단위로 입력함');
@define('UNMET_REQUIREMENTS', '요구사항 불충족: %s');
@define('CHARSET', '문자열 종류');
@define('AUTOLANG', '방문자의 브라우저 언어 설정을 기본으로 따름');
@define('AUTOLANG_DESC', '사용할 경우 방문자의 브라우저 언어 설정을 확인하여 화면에 표시되는 언어 및 글의 언어를 결정합니다.');
@define('INSTALL_AUTODETECT_URL', '사용된 HTTP 호스트를 자동 감지');
@define('INSTALL_AUTODETECT_URL_DESC', '사용할 경우 방문자가 사용한 HTTP 호스트를 세렌디피티가 기본 인터넷 주소로 쓰게 됩니다. 이렇게 되면 세렌디피티 블로그를 여러 개의 도메인 이름 하에 사용할 수 있게 되며, 해당 도메인을 방문자가 블로그를 방문하는데 사용한 추가 링크에 사용할 수 있게 됩니다.');
@define('CONVERT_HTMLENTITIES', 'HTML 본체 자동 변환을 시도하겠습니까?');
@define('EMPTY_SETTING', '"%s"에 대한 유효한 값을 지정하지 않았습니다.');
@define('USERCONF_REALNAME', '실제 이름');
@define('USERCONF_REALNAME_DESC', '작성자의 실제 이름으로써, 독자가 보게 되는 이름입니다.');
@define('HOTLINK_DONE', '파일이 핫링크 되었습니다.<br />완료.');
@define('ENTER_MEDIA_URL_METHOD', '불러오기 방식:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', '주의: 서버에서 핫링크를 하게 될 경우, 해당 사이트에서 핫링크 허락을 받아놓거나 자신의 사이트인 경우에 대해 하기 바랍니다. 핫링크를 하게 되면 외부 그림을 따로 저장하지 않고 쓸 수 있게 됩니다.');
@define('MEDIA_HOTLINKED', '핫링크 됨');
@define('FETCH_METHOD_IMAGE', '이쪽 서버로 그림을 다운로드하기');
@define('FETCH_METHOD_HOTLINK', '서버로 핫링크 걸기');
@define('DELETE_HOTLINK_FILE', '<b>%s</b>(이)라는 핫링크 파일 삭제됨');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', '이메일 주소 표시?');
@define('IMAGE_MORE_INPUT', '그림 추가');
@define('BACKEND_TITLE', '플러그인 설정 화면에 추가 정보 표시');
@define('BACKEND_TITLE_FOR_NUGGET', '플러그인 설정 화면에 HTML 덩어리 플러그인의 설명과 함께 표시될 별도의 문장을 직접 정할 수 있습니다. 제목이 없는 여러 개의 HTML 덩어리를 쓸 경우 각각을 구별하기 쉽게 됩니다.');
@define('CATEGORIES_ALLOW_SELECT', '방문자가 한 번에 여러 개의 범주를 표시할 수 있게 함');
@define('CATEGORIES_ALLOW_SELECT_DESC', '이것을 사용하게 되면 옆줄에 이 플러그인을 통해 표시된 각 범주 옆에 선택 상자가 나타나게 됩니다. 방문자는 이 상자에 체크 표시를 한 다음 선택된 범주에 대한 글을 볼 수 있습니다.');
@define('PAGE_BROWSE_PLUGINS', '%s번째 페이지 | 총 %s 페이지 | 총 %s개의 플러그인');
@define('INSTALL_CAT_PERMALINKS', '고정 링크');
@define('INSTALL_CAT_PERMALINKS_DESC', '블로그 속의 고정 링크를 표시하기 위한 여러 가지의 주소 패턴을 정할 수 있습니다. 가급적 기본값을 사용하십시오. 그러지 않을 경우 가급적이면 %id% 값을 사용하여 세렌디피티가 목적지 주소를 찾아보기 위해 데이터베이스에 질의하는 것을 방지하십시오.');
@define('INSTALL_PERMALINK', '고정 링크 - 작성한 글의 주소 구조');
@define('INSTALL_PERMALINK_DESC', '작성한 글이 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %title%, %day%, %month%, %year% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
@define('INSTALL_PERMALINK_AUTHOR', '고정 링크 - 작성자에 따른 주소 구조');
@define('INSTALL_PERMALINK_AUTHOR_DESC', '특정 작성자가 쓴 글이 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %realname%, %username%, %email% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
@define('INSTALL_PERMALINK_CATEGORY', '고정 링크 - 범주에 따른 주소 구조');
@define('INSTALL_PERMALINK_CATEGORY_DESC', '특정 범주에 속하는 글이 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %name%, %description% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', '고정 링크 - RSS 피드 - 범주에 따른 주소 구조');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', '특정 범주에 속하는 RSS 피드가 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %name%, %description% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', '글 목록으로 가는 경로');
@define('INSTALL_PERMALINK_ARCHIVEPATH', '글 목록으로 가는 경로');
@define('INSTALL_PERMALINK_CATEGORIESPATH', '범주로 가는 경로');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', '덧글을 구독 해지하기 위한 경로');
@define('INSTALL_PERMALINK_DELETEPATH', '덧글을 삭제하기 위한 경로');
@define('INSTALL_PERMALINK_APPROVEPATH', '덧글을 승인하기 위한 경로');
@define('INSTALL_PERMALINK_FEEDSPATH', 'RSS 피드로 가는 경로');
@define('INSTALL_PERMALINK_PLUGINPATH', '하나의 플러그인으로 가는 경로');
@define('INSTALL_PERMALINK_ADMINPATH', '관리 화면으로 가는 경로');
@define('INSTALL_PERMALINK_SEARCHPATH', '검색하기 위한 경로');
@define('INSTALL_CAL', '달력 종류');
@define('INSTALL_CAL_DESC', '원하는 달력의 형태를 고르십시오.');
@define('REPLY', '답글');
@define('USERCONF_GROUPS', '그룹 소속');
@define('USERCONF_GROUPS_DESC', '이 사용자는 다음 그룹에 속해 있습니다. 여러 그룹에 속할 수 있습니다.');
@define('MANAGE_GROUPS', '그룹 관리');
@define('DELETED_GROUP', '%d번 그룹 %s(이)가 삭제되었습니다.');
@define('CREATED_GROUP', '새 그룹 %s(이)가 생성되었습니다.');
@define('MODIFIED_GROUP', '그룹 %s의 설정이 바뀌었습니다.');
@define('GROUP', '그룹');
@define('CREATE_NEW_GROUP', '새 그룹 생성하기');
@define('DELETE_GROUP', '%d번 그룹 %s(을)를 삭제하려고 합니다. 정말입니까?');
@define('USERLEVEL_OBSOLETE', '주의: 사용자 레벨 속성은 플러그인의 하위 호환성 및 인증 대비책을 위해서만 사용되고 있습니다. 현재 사용자 권한 설정은 그룹 소속을 통해 이루어지고 있습니다.');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', '피드버너 아이디');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', '게시하고자 하는 피드의 아이디');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', '피드버너 그림');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', '표시할 그림(feedburner.com에 존재함)의 이름 (fbapix.gif 형태이며, 비워두면 카운터 표시)');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', '피드버너 제목');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', '그림 옆에 표시할 제목 (있을 경우)');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', '피드버너 그림 설명');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', '그림 위에 커서를 댈 때 표시할 설명 (있을 경우)');
@define('INSTALL_DBPORT', '데이터베이스 포트');
@define('INSTALL_DBPORT_DESC', '데이터베이스 서버에 접속할 때 사용하는 포트 번호');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', '일반 페이지: 외부 서비스');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', '일반 페이지: 부가 기능');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', '일반 페이지: 개조 사항');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', '일반 페이지: 표시 상태');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', '일반 페이지: 글 관련');
@define('PLUGIN_GROUP_BACKEND_EDITOR', '관리 페이지: 편집기');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', '관리 페이지: 사용자 관리');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', '관리 페이지: 메타 정보');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', '관리 페이지: 템플릿');
@define('PLUGIN_GROUP_BACKEND_FEATURES', '관리 페이지: 부가 기능');
@define('PLUGIN_GROUP_IMAGES', '그림');
@define('PLUGIN_GROUP_ANTISPAM', '스팸 방지');
@define('PLUGIN_GROUP_MARKUP', '마크업');
@define('PLUGIN_GROUP_STATISTICS', '통계');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: 개인 설정 관리');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: 사용자 레벨 변경');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: "글 생성 금지하기" 설정 변경');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: 글 게시 권한 변경');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: 시스템 설정 관리');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: 블로그 관련 설정 관리');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: 글 관리');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: 다른 사용자의 글 관리');
@define('PERMISSION_ADMINIMPORT', 'adminImport: 글 불러들이기');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: 범주 관리');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: 다른 사용자의 범주 관리');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: 범주 삭제');
@define('PERMISSION_ADMINUSERS', 'adminUsers: 사용자 관리');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: 사용자 삭제');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: 사용자 레벨 변경');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: 자기 그룹에 속한 사용자 관리');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: 다른 그룹에 속한 사용자 관리');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: 새 사용자 생성');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: 사용자 그룹 관리');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: 플러그인 관리');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: 다른 사용자의 플러그인 관리');
@define('PERMISSION_ADMINIMAGES', 'adminImages: 미디어 파일 관리');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: 미디어 디렉토리 관리');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: 새 미디어 파일 추가');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: 미디어 파일 삭제');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: 다른 사용자의 미디어 파일 관리');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: 미디어 파일 보기');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: 작은 그림 동기화');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: 덧글 관리');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: 템플릿 관리');
@define('INSTALL_BLOG_EMAIL', '블로그의 전자우편 주소');
@define('INSTALL_BLOG_EMAIL_DESC', '발송하는 전자우편의 "보낸 사람" 부분에 나타날 전자우편 주소를 설정합니다. 호스트의 메일 서버에서 인식하는 주소로 반드시 설정하십시오. 상당수의 메일 서버는 보낸 사람 주소를 알 수 없는 전자우편을 거부합니다.');
@define('CATEGORIES_PARENT_BASE', '하위 범주만 보이기');
@define('CATEGORIES_PARENT_BASE_DESC', '하나의 상위 범주를 골라서 그 아래에 있는 범주만 보이도록 할 수 있습니다.');
@define('CATEGORIES_HIDE_PARALLEL', '범주 트리에 속하지 않는 범주 숨기기');
@define('CATEGORIES_HIDE_PARALLEL_DESC', '다른 범주 트리에 속해 있는 범주를 보이지 않게 하려면 이것을 사용하십시오. "범주의 속성/템플릿" 플러그인을 적용한 멀티-블로그와 함께 사용할 때 가장 의미가 있습니다.');

@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: 다른 사용자의 미디어 파일 보기');
@define('CHARSET_NATIVE', '지역 전용');
@define('INSTALL_CHARSET', '문자열 종류 선택');
@define('INSTALL_CHARSET_DESC', '여기서 문자열을 UTF-8로 할 것인지 지역 전용 (ISO, EUC 등)으로 할 것인지 정할 수 있습니다. 일부 언어는 UTF-8 버전만 제공되므로 "지역 전용"을 설정해도 변화가 없습니다. 새로 설치한 경우 UTF-8을 권장합니다. 이미 특별 문자를 사용하여 글을 작성했을 경우 이 설정을 변경하지 마십시오. 글자가 깨질 수 있습니다. 이 설정에 대해서는 http://www.s9y.org/index.php?node=46 에 더 자세하게 소개가 되어 있습니다.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', '플러그인 API 훅 사용');
@define('CALENDAR_EXTEVENT_DESC', '사용할 경우, 플러그인은 달력에 훅을 걸어서 자체적인 이벤트를 강조 표시할 수 있게 됩니다. 이 기능이 필요한 플러그인을 설치했을 때만 사용하십시오. 그냥 켜놓게 되면 성능만 떨어뜨립니다.');
@define('XMLRPC_NO_LONGER_BUNDLED', '세렌디피티에 대한 XML-RPC API 인터페이스는 지속적으로 보안 상의 문제가 지적되고 있고 사용자 수가 적은 관계로 더 이상 기본적으로 포함되어 있지 않습니다. 그러므로 XML-RPC API를 사용하기 위해서는 XML-RPC 플러그인을 설치해야 합니다. 기존 어플리케이션에 사용하던 주소에는 변함이 없습니다. 플러그인을 설치하게 되면 곧바로 API를 사용할 수 있게 됩니다.');
@define('PERM_READ', '읽기 권한');
@define('PERM_WRITE', '쓰기 권한');

@define('PERM_DENIED', '권한이 없습니다.');
@define('INSTALL_ACL', '범주에 대한 읽기 권한 적용');
@define('INSTALL_ACL_DESC', '사용할 경우, 로그인한 사용자가 당신의 블로그를 읽을 때 각 범주에 대해 지정한 사용자 권한 설정이 적용됩니다. 사용하지 않을 경우 범주에 대한 읽기 권한이 적용되지 않게 되지만 블로그 속도가 약간 빨라지는 장점이 있습니다. 그러므로 블로그에 대한 다중 사용자 읽기 권한이 필요 없다면 이 설정을 끄십시오.');
@define('PLUGIN_API_VALIDATE_ERROR', '옵션 "%s"에 대한 설정 구문이 잘못되었습니다. "%s" 종류에 해당하는 내용이 필요합니다.');
@define('USERCONF_CHECK_PASSWORD', '이전 암호');
@define('USERCONF_CHECK_PASSWORD_DESC', '위의 적힌 암호를 변경하려면 여기에 현재 사용중인 암호를 적으십시오.');
@define('USERCONF_CHECK_PASSWORD_ERROR', '이전 암호가 올바르지 않으므로 새 암호로 변경할 권한이 없습니다. 설정이 저장되지 않았습니다.');
@define('ERROR_XSRF', '브라우저가 유효한 HTTP 진입자(referrer) 문자열을 보내지 않았습니다. 브라우저/프록시 설정이 잘못되었거나 당신을 겨냥한 상호 사이트 요청 위조(XSRF) 때문이었을 수 있습니다. 요청한 사항을 처리할 수 없었습니다.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', '특정 사용자의 RSS 피드를 보기 위한 상대적인 인터넷 주소 구조를 %id%, %realname%, %username%, %email% 등의 변수와 일반 글자를 활용해서 정의할 수 있습니다. 전체 주소는 사이트의 기본 주소를 기초로 해서 시작합니다.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', '작성자에 따른 RSS 피드 고정 링크 주소 구조');
@define('INSTALL_PERMALINK_AUTHORSPATH', '작성자로의 경로');
@define('AUTHORS', '작성자');
@define('AUTHORS_ALLOW_SELECT', '방문자가 한 번에 여러 작성자의 글을 볼 수 있게 합니까?');
@define('AUTHORS_ALLOW_SELECT_DESC', '사용할 경우, 이 플러그인에 의해 표시되는 각 작성자 이름 옆에 체크박스가 표시됩니다. 선택 여부에 따라 원하는 조건의 글을 볼 수 있게 됩니다.');
@define('AUTHOR_PLUGIN_DESC', '작성자의 목록 보이기');
@define('CATEGORY_PLUGIN_TEMPLATE', '스마티 템플릿 사용');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', '사용할 경우, 이 플러그인은 스마티 템플릿 기능을 활용하여 범주 목록을 출력하게 됩니다. 구성은 "plugin_categories.tpl" 템플릿 파일을 편집하여 고칠 수 있습니다. 성능 저하를 가져오게 되므로 특화시키지 않을 경우 꺼두십시오.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', '범주 당 글의 수 보이기');
@define('AUTHORS_SHOW_ARTICLE_COUNT', '작성자 이름 옆에 글의 수 보이기');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', '사용할 경우, 각 작성자의 이름 옆 괄호 속에 해당 작성자가 쓴 글의 수를 표시합니다.');
@define('CUSTOM_ADMIN_INTERFACE', 'Custom admin interface available');

@define('COMMENT_NOT_ADDED', '덧글 금지가 되어 있어 덧글을 추가하지 못했습니다. '); // Retranslate: 'Your comment could not be added, because comments for this entry have either been disabled, you entered invalid data, or your comment was caught by anti-spam measurements.'
@define('INSTALL_TRACKREF', 'Enable referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Enabling the referrer tracking will show you which sites refer to your articles. Today this is often abused for spamming, so you can disable it if you want.');
@define('CATEGORIES_HIDE_PARENT', 'Hide the selected parent category?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'If you restrict the listing of categories to a specific category, by default you will see that parent category within the output listing. If you disable this option, the parent category name will not be displayed.');
@define('WARNING_NO_GROUPS_SELECTED', 'Warning: You did not select any group memberships. This would effectively log you out of the usergroup management, and thus your group memberships werde not changed.');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comment removed)');

@define('CURRENT_AUTHOR', 'Current author');

@define('WORD_NEW', 'New');
@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
@define('MEDIA_KEYWORDS', 'Media keywords');
@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
@define('MEDIA_PROP', 'Media properties');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
@define('MEDIA_PROPERTY_TITLE', 'Title');
@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');

@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Theme/Style options');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Associated Date');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
@define('MEDIA_ENTRY', 'Isolated Entry');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');

@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Active');
@define('PLUGIN_INACTIVE', 'Inactive');
@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');

@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
